package kr.co.vividnext.sodalive.audio_content.main.v2

import android.annotation.SuppressLint
import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.bumptech.glide.load.MultiTransformation
import com.bumptech.glide.load.resource.bitmap.CenterCrop
import com.bumptech.glide.load.resource.bitmap.CircleCrop
import com.bumptech.glide.load.resource.bitmap.RoundedCorners
import com.bumptech.glide.request.RequestOptions
import kr.co.vividnext.sodalive.R
import kr.co.vividnext.sodalive.audio_content.main.GetAudioContentRankingItem
import kr.co.vividnext.sodalive.databinding.ItemAudioContentMainTabPopularContentBinding
import kr.co.vividnext.sodalive.extensions.dpToPx
import kr.co.vividnext.sodalive.extensions.moneyFormat

class PopularContentByCreatorAdapter(
    private val itemWidth: Int,
    private val onClickItem: (Long) -> Unit,
    private val onClickCreator: (Long) -> Unit
) : RecyclerView.Adapter<PopularContentByCreatorAdapter.ViewHolder>() {

    private val items = mutableListOf<GetAudioContentRankingItem>()

    inner class ViewHolder(
        private val context: Context,
        private val binding: ItemAudioContentMainTabPopularContentBinding
    ) : RecyclerView.ViewHolder(binding.root) {

        fun bind(item: GetAudioContentRankingItem) {
            val lp = binding.ivCover.layoutParams as ConstraintLayout.LayoutParams
            lp.width = itemWidth
            lp.height = itemWidth
            binding.ivCover.layoutParams = lp

            Glide
                .with(context)
                .load(item.coverImageUrl)
                .apply(
                    RequestOptions().transform(
                        MultiTransformation(
                            CenterCrop(),
                            RoundedCorners(5.3f.dpToPx().toInt())
                        )
                    )
                )
                .placeholder(R.drawable.bg_black)
                .into(binding.ivCover)

            Glide
                .with(context)
                .load(item.creatorProfileImageUrl)
                .apply(
                    RequestOptions().transform(
                        CircleCrop()
                    )
                )
                .placeholder(R.drawable.bg_black)
                .into(binding.ivCreator)

            binding.tvTitle.text = item.title
            binding.tvNickname.text = item.creatorNickname

            if (item.price > 0) {
                binding.ivCan.visibility = View.VISIBLE
                binding.tvCan.text = item.price.moneyFormat()
            } else {
                binding.ivCan.visibility = View.GONE
                binding.tvCan.text = "무료"
            }

            binding.tvTime.text = item.duration

            binding.ivCover.setOnClickListener { onClickItem(item.contentId) }
            binding.ivCreator.setOnClickListener { onClickCreator(item.creatorId) }
            binding.tvNickname.setOnClickListener { onClickCreator(item.creatorId) }
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int) = ViewHolder(
        parent.context,
        ItemAudioContentMainTabPopularContentBinding.inflate(
            LayoutInflater.from(parent.context),
            parent,
            false
        )
    )

    override fun getItemCount() = items.size

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        holder.bind(items[position])
    }

    @SuppressLint("NotifyDataSetChanged")
    fun addItems(items: List<GetAudioContentRankingItem>) {
        this.items.clear()
        this.items.addAll(items)
        notifyDataSetChanged()
    }
}
